@@ -1,4 +1,5 @@
-/* vim: set sw=4: -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* vim: set sw=4 sts=4 ts=4 expandtab: */
 /*
    rsvg-cairo-render.h: The cairo backend plugin
 
@@ -31,11 +32,9 @@
 #include "rsvg-cairo-render.h"
 #include <cairo.h>
 
-G_BEGIN_DECLS
+G_BEGIN_DECLS 
 
-void 
-rsvg_cairo_clip (RsvgDrawingCtx *ctx, RsvgClipPath *clip, 
-				 RsvgBbox *bbox);
+void rsvg_cairo_clip (RsvgDrawingCtx * ctx, RsvgClipPath * clip, RsvgBbox * bbox);
 
 G_END_DECLS
 
